@@ -118,6 +118,9 @@ panel_context_menu_show_about_dialog (GtkWidget *menuitem)
 	for (i = 0; authors [i]; i++)
 		authors [i] = _(authors [i]);
 
+	/* Note: we don't use gtk_show_about_dialog() since some applets can
+	 * be loaded in this process and we don't want to share the about
+	 * dialog */
 	about = gtk_about_dialog_new ();
 	g_object_set (about,
 		      "name",  _("The GNOME Panel"),
@@ -141,6 +144,10 @@ panel_context_menu_show_about_dialog (GtkWidget *menuitem)
 			  G_CALLBACK (panel_context_menu_check_for_screen),
 			  NULL);
 
+	g_signal_connect (about, "response",
+			  G_CALLBACK (gtk_widget_destroy),
+			  NULL);
+
 	gtk_widget_show (about);
 }
 
@@ -161,10 +168,10 @@ panel_context_menu_remove_panel (GtkWidget *menuitem,
 	toplevel     = panel_widget->toplevel;
 
 	if (panel_toplevel_is_last_unattached (toplevel)) {
-		panel_error_dialog (menuitem_to_screen (menuitem),
+		panel_error_dialog (NULL, menuitem_to_screen (menuitem),
 				    "cannot_remove_last_panel", TRUE,
-				    _("You cannot remove your last panel."),
-				    NULL);
+				    _("Cannot delete this panel"),
+				    _("You must always have at least one panel."));
 		return;
 	}
 
@@ -184,9 +191,9 @@ panel_context_menu_setup_remove_panel_item (GtkWidget *menu,
 	g_assert (PANEL_IS_TOPLEVEL (panel_widget->toplevel));
 
 	sensitive =
-		panel_toplevel_is_last_unattached (panel_widget->toplevel) ||
-		!panel_lockdown_get_locked_down () ||
-		!panel_profile_id_lists_are_writable ();
+		!panel_toplevel_is_last_unattached (panel_widget->toplevel) &&
+		!panel_lockdown_get_locked_down () &&
+		panel_profile_id_lists_are_writable ();
 
 	gtk_widget_set_sensitive (menuitem, sensitive);
 
@@ -203,7 +210,7 @@ panel_context_menu_setup_remove_panel_item (GtkWidget *menu,
 		g_list_free (list);
 	}
 	if (!GTK_IS_LABEL (label)) {
-		g_warning ("We can't find the label of a menu item");
+		g_warning ("Cannot find the label of a menu item");
 		return;
 	}
 
