@@ -404,7 +404,8 @@ panel_menu_bar_load (PanelWidget *panel,
 				   _("_Help"),
 				   NULL);
 
-	if (panel_is_program_in_path ("gmenu-simple-editor")) {
+	if (panel_is_program_in_path ("alacarte") ||
+	    panel_is_program_in_path ("gmenu-simple-editor")) {
 		panel_applet_add_callback (menubar->priv->info,
 					   "edit",
 					   NULL,
@@ -461,17 +462,26 @@ panel_menu_bar_invoke_menu (PanelMenuBar *menubar,
 	} else if (!strcmp (callback_name, "edit")) {
 		GError *error = NULL;
 
-		panel_launch_desktop_file ("gmenu-simple-editor.desktop",
-					   "gmenu-simple-editor",
+		panel_launch_desktop_file ("alacarte.desktop",
+					   "alacarte",
 					   screen,
 					   &error);
 		if (error) {
-			panel_error_dialog (screen,
-					    "cannot_exec_gmenu-simple-editor", TRUE,
-					    _("Could not execute '%s'"),
-					    "%s",
-					    "gmenu-simple-editor",
-					    error->message);
+			g_error_free (error);
+			panel_launch_desktop_file ("gmenu-simple-editor.desktop",
+						   "gmenu-simple-editor",
+						   screen,
+						   &error);
+		}
+		if (error) {
+			char *primary;
+			primary = g_strdup_printf (_("Could not execute '%s'"),
+						   "gmenu-simple-editor");
+                        panel_error_dialog (NULL, screen,
+                                            "cannot_exec_gmenu-simple-editor",
+					    TRUE,
+					    primary, error->message);
+			g_free (primary);
 			g_error_free (error);
 		}
 	}
