@@ -65,7 +65,7 @@ struct _PanelPlaceMenuItemPrivate {
 	GtkWidget   *menu;
 	PanelWidget *panel;
 
-	EggRecentViewGtk *recent_view;
+	GtkRecentManager *recent_manager;
 
 	GnomeVFSMonitorHandle *bookmarks_monitor;
 
@@ -105,13 +105,15 @@ activate_uri (GtkWidget *menuitem,
 
 	if (error != NULL) {
 		if (error->code != GNOME_URL_ERROR_CANCELLED) {
+			char *primary;
 			escaped = g_markup_escape_text (url, -1);
-			panel_error_dialog (screen, "cannot_show_url", TRUE,
-					    _("Could not open location '%s'"),
-					    "%s",
-					    escaped,
-					    error->message);
+			primary = g_strdup_printf (_("Could not open location '%s'"),
+						   escaped);
 			g_free (escaped);
+			panel_error_dialog (NULL, screen,
+					    "cannot_show_url", TRUE,
+					    primary, error->message);
+			g_free (primary);
 		}
 		g_error_free (error);
 	}
@@ -170,14 +172,11 @@ panel_menu_items_append_from_desktop (GtkWidget *menu,
 		return;
 	}
 
-	icon    = g_key_file_get_locale_string (key_file, "Desktop Entry",
-						"Icon", NULL, NULL);
-	comment = g_key_file_get_locale_string (key_file, "Desktop Entry",
-						"Comment", NULL, NULL);
+	icon    = panel_util_key_file_get_locale_string (key_file, "Icon");
+	comment = panel_util_key_file_get_locale_string (key_file, "Comment");
 
 	if (string_empty (force_name))
-		name = g_key_file_get_locale_string (key_file, "Desktop Entry",
-						     "Name", NULL, NULL);
+		name = panel_util_key_file_get_locale_string (key_file, "Name");
 	else
 		name = g_strdup (force_name);
 
@@ -424,7 +423,7 @@ panel_place_menu_item_append_gtk_bookmarks (GtkWidget *menu)
 				if (!path || !path[0])
 					displayname = g_strdup ("/");
 				else
-					displayname = g_filename_display_basename (path);
+					displayname = gnome_vfs_unescape_string_for_display (path);
 				if (hostname) {
 					/* Translators: the first string is a
 					 * path and the second string is a
@@ -551,7 +550,7 @@ panel_place_menu_item_append_volumes (GtkWidget *menu,
 
 
 static GtkWidget *
-panel_place_menu_item_create_menu (EggRecentViewGtk **recent_view)
+panel_place_menu_item_create_menu (PanelPlaceMenuItem *place_item)
 {
 	GtkWidget *places_menu;
 	GtkWidget *item;
@@ -620,8 +619,8 @@ panel_place_menu_item_create_menu (EggRecentViewGtk **recent_view)
 					      "gnome-search-tool.desktop",
 					      NULL);
 
-	*recent_view = panel_recent_append_documents_menu (places_menu,
-							   *recent_view);
+	panel_recent_append_documents_menu (places_menu,
+					    place_item->priv->recent_manager);
 
 	return places_menu;
 }
@@ -635,7 +634,7 @@ panel_place_menu_item_recreate_menu (GtkWidget *widget)
 
 	if (place_item->priv->menu) {
 		gtk_widget_destroy (place_item->priv->menu);
-		place_item->priv->menu = panel_place_menu_item_create_menu (&place_item->priv->recent_view);
+		place_item->priv->menu = panel_place_menu_item_create_menu (place_item);
 		gtk_menu_item_set_submenu (GTK_MENU_ITEM (place_item),
 					   place_item->priv->menu);
 		panel_applet_menu_set_recurse (GTK_MENU (place_item->priv->menu),
@@ -748,10 +747,6 @@ panel_place_menu_item_finalize (GObject *object)
 				 NAMES_DIR,
 				 NULL);
 
-	if (menuitem->priv->recent_view != NULL)
-		g_object_unref (menuitem->priv->recent_view);
-	menuitem->priv->recent_view = NULL;
-
 	if (menuitem->priv->bookmarks_monitor != NULL)
 		gnome_vfs_monitor_cancel (menuitem->priv->bookmarks_monitor);
 	menuitem->priv->bookmarks_monitor = NULL;
@@ -808,6 +803,8 @@ panel_place_menu_item_instance_init (PanelPlaceMenuItem      *menuitem,
 					    (GConfClientNotifyFunc) panel_place_menu_item_key_changed,
 					    G_OBJECT (menuitem));
 
+	menuitem->priv->recent_manager = gtk_recent_manager_get_default ();
+
 	bookmarks_filename = g_build_filename (g_get_home_dir (),
 					       BOOKMARKS_FILENAME, NULL);
 	bookmarks_uri = gnome_vfs_get_uri_from_local_path (bookmarks_filename);
@@ -958,7 +955,7 @@ panel_place_menu_item_new (gboolean use_image)
 					       image);
 	}
 
-	menuitem->priv->menu = panel_place_menu_item_create_menu (&menuitem->priv->recent_view);
+	menuitem->priv->menu = panel_place_menu_item_create_menu (menuitem);
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem),
 				   menuitem->priv->menu);
 
@@ -974,10 +971,7 @@ panel_desktop_menu_item_new (gboolean use_image,
 
 	menuitem = g_object_new (PANEL_TYPE_DESKTOP_MENU_ITEM, NULL);
 
-	/* Translators: Desktop is used here as in "Desktop Environment" (this
-	 * is not the Desktop folder). Do not keep "Desktop Environment|" in
-	 * the translation. */
-	accel_label = gtk_accel_label_new (Q_("Desktop Environment|Desktop"));
+	accel_label = gtk_accel_label_new (_("System"));
 	gtk_misc_set_alignment (GTK_MISC (accel_label), 0.0, 0.5);
 
 	gtk_container_add (GTK_CONTAINER (menuitem), accel_label);
@@ -1118,34 +1112,17 @@ void
 panel_menu_item_activate_desktop_file (GtkWidget  *menuitem,
 				       const char *path)
 {
-	GnomeDesktopItem *item;
-	GError           *error;
+	GError *error;
 
 	error = NULL;
-	item = gnome_desktop_item_new_from_file (path, 0, &error);
-	if (item) {
-		g_assert (error == NULL);
-
-		panel_ditem_launch (item, NULL, 0,
-				    menuitem_to_screen (menuitem), &error);
-		if (error) {
-			panel_error_dialog (menuitem_to_screen (menuitem),
-					    "cannot_launch_entry", TRUE,
-					    _("Could not launch menu item"),
-					    "%s",
-					    error->message);
-
-			g_error_free (error);
-		}
-		gnome_desktop_item_unref (item);
-	} else {
-		g_assert (error != NULL);
-
-		panel_error_dialog (menuitem_to_screen (menuitem),
-				    "cannot_load_entry", TRUE,
-				    _("Could not load menu item"),
-				    "%s",
+	panel_launch_desktop_file (path, NULL,
+				   menuitem_to_screen (menuitem), &error);
+	if (error) {
+		panel_error_dialog (NULL, menuitem_to_screen (menuitem),
+				    "cannot_launch_entry", TRUE,
+				    _("Could not launch menu item"),
 				    error->message);
+
 		g_error_free (error);
 	}
 }
